@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/python
 # -*- coding: utf-8 -*-
 # vim: sw=8:ts=8:noexpandtab
 
@@ -22,12 +22,32 @@
 
 import sys
 import re
-import subprocess
+from subprocess import Popen, PIPE
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
 
 app_name = "ReText"
-app_version = "3.0.0"
+app_version = "3.1.0"
+
+def readFromSettings(settings, key, keytype):
+	try:
+		return settings.value(key, type=keytype)
+	except TypeError as error:
+		if str(error).startswith('unable to convert'):
+			# New PyQt version, but type mismatch
+			print('Warning: '+str(error))
+			# Return an instance of keytype
+			return keytype()
+		# For old PyQt versions
+		if keytype == str:
+			return settings.value(key).toString()
+		elif keytype == int:
+			result, ok = settings.value(key).toInt()
+			if not ok:
+				print('Warning: cannot covert settings value to int!')
+			return result
+		elif keytype == bool:
+			return settings.value(key).toBool()
 
 def readListFromSettings(settings, key):
 	if not settings.contains(key):
@@ -62,9 +82,13 @@ else:
 	if settings.contains('mdExtensions'):
 		for ext in readListFromSettings(settings, 'mdExtensions'):
 			exts.append(str(ext))
-		md = markdown.Markdown(exts)
+		try:
+			md = markdown.Markdown(exts, output_format='html4')
+		except ValueError:
+			print('Warning: failed to load extensions!')
+			md = markdown.Markdown(output_format='html4')
 	else:
-		md = markdown.Markdown()
+		md = markdown.Markdown(output_format='html4')
 
 try:
 	import gdata.docs.data
@@ -83,8 +107,6 @@ except:
 else:
 	use_enchant = True
 
-dictionary = None
-
 try:
 	from docutils.core import publish_parts
 except:
@@ -94,7 +116,8 @@ else:
 
 icon_path = "icons/"
 
-PARSER_DOCUTILS, PARSER_MARKDOWN, PARSER_HTML, PARSER_NA = range(4)
+PARSER_DOCUTILS, PARSER_MARKDOWN, PARSER_NA = range(3)
+DOCTYPE_PLAINTEXT, DOCTYPE_REST, DOCTYPE_MARKDOWN, DOCTYPE_HTML = range(4)
 
 if QFileInfo("wpgen/wpgen.py").isExecutable():
 	try:
@@ -109,11 +132,11 @@ else:
 
 monofont = QFont()
 if settings.contains('editorFont'):
-	monofont.setFamily(settings.value('editorFont', type='QString'))
+	monofont.setFamily(readFromSettings(settings, 'editorFont', str))
 else:
 	monofont.setFamily('monospace')
 if settings.contains('editorFontSize'):
-	monofont.setPointSize(settings.value('editorFontSize', type=int))
+	monofont.setPointSize(readFromSettings(settings, 'editorFontSize', int))
 
 try:
 	from PyQt4.QtWebKit import QWebView, QWebSettings
@@ -123,23 +146,33 @@ else:
 	webkit_available = True
 
 class ReTextHighlighter(QSyntaxHighlighter):
+	dictionary = None
+	docType = DOCTYPE_PLAINTEXT
+	
 	def highlightBlock(self, text):
 		patterns = (
-			('<[^<>]*>', Qt.darkMagenta, QFont.Bold),          # HTML tags
-			('&[^; ]*;', Qt.darkCyan, QFont.Bold),             # HTML symbols
-			('"[^"<]*"(?=[^<]*>)', Qt.darkYellow, QFont.Bold), # Quoted strings inside tags
-			('<!--[^<>]*-->', Qt.gray, QFont.Normal),          # HTML comments
-			('(?<!\\*)\\*[^ \\*][^\\*]*\\*', None, QFont.Normal, True), # *Italics*
-			('(?<!_|\\w)_[^_]+_(?!\\w)', None, QFont.Normal, True),     # _Italics_
-			('(?<!\\*)\\*\\*((?!\\*\\*).)*\\*\\*', None, QFont.Bold), # **Bold**
-			('(?<!_|\\w)__[^_]+__(?!\\w)', None, QFont.Bold),         # __Bold__
-			('\\*{3,3}[^\\*]+\\*{3,3}', None, QFont.Bold, True), # ***BoldItalics***
-			('___[^_]+___', None, QFont.Bold, True),           # ___BoldItalics___
-			('^#.+', None, QFont.Black),                       # Headers
-			('(?<=\\[)[^\\[\\]]*(?=\\])', Qt.blue, QFont.Normal), # Links and images
-			('(?<=\\]\\()[^\\(\\)]*(?=\\))', None, QFont.Normal, True, True) # Link references
+			('<[^<>@]*>', Qt.darkMagenta, QFont.Bold),         # 0: HTML tags
+			('&[^; ]*;', Qt.darkCyan, QFont.Bold),             # 1: HTML symbols
+			('"[^"<]*"(?=[^<]*>)', Qt.darkYellow, QFont.Bold), # 2: Quoted strings inside tags
+			('<!--[^<>]*-->', Qt.gray, QFont.Normal),          # 3: HTML comments
+			('(?<!\\*)\\*[^ \\*][^\\*]*\\*', None, QFont.Normal, True), # 4: *Italics*
+			('(?<!_|\\w)_[^_]+_(?!\\w)', None, QFont.Normal, True),     # 5: _Italics_
+			('(?<!\\*)\\*\\*((?!\\*\\*).)*\\*\\*', None, QFont.Bold), # 6: **Bold**
+			('(?<!_|\\w)__[^_]+__(?!\\w)', None, QFont.Bold),         # 7: __Bold__
+			('\\*{3,3}[^\\*]+\\*{3,3}', None, QFont.Bold, True), # 8: ***BoldItalics***
+			('___[^_]+___', None, QFont.Bold, True),           # 9: ___BoldItalics___
+			('^#.+', None, QFont.Black),                       # 10: Headers
+			('(?<=\\[)[^\\[\\]]*(?=\\])', Qt.blue, QFont.Normal), # 11: Links and images
+			('(?<=\\]\\()[^\\(\\)]*(?=\\))', None, QFont.Normal, True, True) # 12: Link references
 		)
-		for pattern in patterns:
+		patternsDict = {
+			DOCTYPE_PLAINTEXT: (),
+			DOCTYPE_MARKDOWN: (0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12),
+			DOCTYPE_REST: (4, 6),
+			DOCTYPE_HTML: (0, 1, 2, 3)
+		}
+		for number in patternsDict[self.docType]:
+			pattern = patterns[number]
 			charFormat = QTextCharFormat()
 			charFormat.setFontWeight(pattern[2])
 			if pattern[1] != None:
@@ -150,7 +183,7 @@ class ReTextHighlighter(QSyntaxHighlighter):
 				charFormat.setFontUnderline(pattern[4])
 			for match in re.finditer(pattern[0], text):
 				self.setFormat(match.start(), match.end() - match.start(), charFormat)
-		if dictionary:
+		if self.dictionary:
 			try:
 				text = unicode(text)
 			except:
@@ -163,7 +196,7 @@ class ReTextHighlighter(QSyntaxHighlighter):
 				finalFormat = QTextCharFormat()
 				finalFormat.merge(charFormat)
 				finalFormat.merge(self.format(match.start()))
-				if not dictionary.check(match.group(0)):
+				if not self.dictionary.check(match.group(0)):
 					self.setFormat(match.start(), match.end() - match.start(), finalFormat)
 
 class LogPassDialog(QDialog):
@@ -200,7 +233,8 @@ class HtmlDialog(QDialog):
 		self.textEdit = QTextEdit(self)
 		self.textEdit.setReadOnly(True)
 		self.textEdit.setFont(monofont)
-		ReTextHighlighter(self.textEdit.document())
+		hl = ReTextHighlighter(self.textEdit.document())
+		hl.docType = DOCTYPE_HTML
 		self.verticalLayout.addWidget(self.textEdit)
 		self.buttonBox = QDialogButtonBox(self)
 		self.buttonBox.setStandardButtons(QDialogButtonBox.Close)
@@ -218,11 +252,19 @@ class ReTextWindow(QMainWindow):
 		size = self.geometry()
 		self.move((screen.width()-size.width())/2, (screen.height()-size.height())/2)
 		if settings.contains('iconTheme'):
-			QIcon.setThemeName(settings.value('iconTheme', type='QString'))
+			QIcon.setThemeName(readFromSettings(settings, 'iconTheme', str))
+		if QIcon.themeName() in ('', 'hicolor'):
+			try:
+				gconf = Popen(['gconftool-2', '--get', '/desktop/gnome/interface/icon_theme'],
+				stdout=PIPE)
+			except: pass
+			else:
+				iconTheme = gconf.stdout.read().rstrip()
+				if iconTheme: QIcon.setThemeName(iconTheme.decode())
 		if settings.contains('font'):
-			self.font = QFont(settings.value('font', type='QString'))
+			self.font = QFont(readFromSettings(settings, 'font', str))
 			if settings.contains('fontSize'):
-				self.font.setPointSize(settings.value('fontSize', type=int))
+				self.font.setPointSize(readFromSettings(settings, 'fontSize', int))
 		else:
 			self.font = None
 		if QFile.exists(icon_path+'retext.png'):
@@ -276,24 +318,17 @@ class ReTextWindow(QMainWindow):
 			self.actionPreview.setIcon(QIcon.fromTheme('x-office-document'))
 		else:
 			self.actionPreview.setIcon(QIcon(icon_path+'document-preview.png'))
-		self.actionLivePreview = self.act(self.tr('Live preview'), shct=Qt.CTRL+Qt.SHIFT+Qt.Key_E, \
+		self.actionLivePreview = self.act(self.tr('Live preview'), shct=Qt.CTRL+Qt.Key_L, \
 		trigbool=self.enableLivePreview)
 		self.actionFullScreen = self.act(self.tr('Fullscreen mode'), icon='view-fullscreen', shct=Qt.Key_F11, \
 		trigbool=self.enableFullScreen)
 		self.actionPerfectHtml = self.act('HTML', icon='text-html', trig=self.saveFilePerfect)
 		self.actionPdf = self.act('PDF', icon='application-pdf', trig=self.savePdf)
 		self.actionOdf = self.act('ODT', icon='x-office-document', trig=self.saveOdf)
-		settings.beginGroup('Export')
-		if settings.allKeys():
-			self.actionOtherExport = self.act(self.tr('Other formats'), trig=self.otherExport)
-			otherExport = True
-		else:
-			otherExport = False
-		settings.endGroup()
 		self.getExportExtensionsList()
 		self.actionQuit = self.act(self.tr('Quit'), icon='application-exit', shct=QKeySequence.Quit)
 		self.actionQuit.setMenuRole(QAction.QuitRole)
-		self.connect(self.actionQuit, SIGNAL('triggered()'), qApp, SLOT('quit()'))
+		self.connect(self.actionQuit, SIGNAL('triggered()'), self.close)
 		self.actionUndo = self.act(self.tr('Undo'), icon='edit-undo', shct=QKeySequence.Undo, \
 		trig=lambda: self.editBoxes[self.ind].undo())
 		self.actionRedo = self.act(self.tr('Redo'), icon='edit-redo', shct=QKeySequence.Redo, \
@@ -310,24 +345,15 @@ class ReTextWindow(QMainWindow):
 		self.actionCut.setEnabled(False)
 		self.connect(qApp.clipboard(), SIGNAL('dataChanged()'), self.clipboardDataChanged)
 		self.clipboardDataChanged()
-		self.sc = False
 		if use_enchant:
 			self.actionEnableSC = self.act(self.tr('Enable'), trigbool=self.enableSC)
 			self.actionSetLocale = self.act(self.tr('Set locale'), trig=self.changeLocale)
-			if settings.contains('spellCheckLocale'):
-				self.sl = str(settings.value('spellCheckLocale', type='QString'))
-			else:
-				self.sl = None
-			if settings.contains('spellCheck'):
-				if settings.value('spellCheck', type=bool):
-					self.actionEnableSC.setChecked(True)
-					self.enableSC(True)
 		self.actionPlainText = self.act(self.tr('Plain text'), trigbool=self.enablePlainText)
 		if webkit_available:
 			self.actionWebKit = self.act(self.tr('Use WebKit renderer'), trigbool=self.enableWebKit)
 			self.useWebKit = False
 			if settings.contains('useWebKit'):
-				if settings.value('useWebKit', type=bool):
+				if readFromSettings(settings, 'useWebKit', bool):
 					self.useWebKit = True
 					self.actionWebKit.setChecked(True)
 		if wpgen:
@@ -348,15 +374,15 @@ class ReTextWindow(QMainWindow):
 		self.actionAboutQt.setMenuRole(QAction.AboutQtRole)
 		self.connect(self.actionAboutQt, SIGNAL('triggered()'), qApp, SLOT('aboutQt()'))
 		self.chooseGroup = QActionGroup(self)
-		self.useDocUtils = False
+		self.defaultDocType = DOCTYPE_MARKDOWN
 		self.actionUseMarkdown = self.act('Markdown')
 		self.actionUseMarkdown.setCheckable(True)
 		self.actionUseReST = self.act('ReStructuredText')
 		self.actionUseReST.setCheckable(True)
 		if settings.contains('useReST'):
-			if settings.value('useReST', type=bool):
+			if readFromSettings(settings, 'useReST', bool):
 				if use_docutils:
-					self.useDocUtils = True
+					self.defaultDocType = DOCTYPE_REST
 				self.actionUseReST.setChecked(True)
 			else:
 				self.actionUseMarkdown.setChecked(True)
@@ -385,7 +411,7 @@ class ReTextWindow(QMainWindow):
 		self.symbolBox.addItems(self.usefulChars)
 		self.connect(self.symbolBox, SIGNAL('activated(int)'), self.insertSymbol)
 		if settings.contains('styleSheet'):
-			ssname = settings.value('styleSheet', type='QString')
+			ssname = readFromSettings(settings, 'styleSheet', str)
 			sheetfile = QFile(ssname)
 			sheetfile.open(QIODevice.ReadOnly)
 			self.ss = QTextStream(sheetfile).readAll()
@@ -398,8 +424,7 @@ class ReTextWindow(QMainWindow):
 			# Load CSS style for codehilite
 			try:
 				from pygments.formatters import HtmlFormatter
-			except:
-				pass
+			except: pass
 			else:
 				self.ss += HtmlFormatter().get_style_defs('.codehilite')
 		self.menubar = QMenuBar(self)
@@ -430,8 +455,6 @@ class ReTextWindow(QMainWindow):
 			for action, mimetype in self.extensionActions:
 				self.menuExport.addAction(action)
 			self.connect(self.menuRecentFiles, SIGNAL('aboutToShow()'), self.updateExtensionsVisibility)
-		if otherExport:
-			self.menuExport.addAction(self.actionOtherExport)
 		if use_gdocs:
 			self.menuExport.addSeparator()
 			self.menuExport.addAction(self.actionSaveGDocs)
@@ -446,6 +469,7 @@ class ReTextWindow(QMainWindow):
 		self.menuEdit.addAction(self.actionCopy)
 		self.menuEdit.addAction(self.actionPaste)
 		self.menuEdit.addSeparator()
+		self.sc = False
 		if use_enchant:
 			self.menuSC = self.menuEdit.addMenu(self.tr('Spell check'))
 			self.menuSC.addAction(self.actionEnableSC)
@@ -497,8 +521,7 @@ class ReTextWindow(QMainWindow):
 		self.searchEdit = QLineEdit(self.searchBar)
 		try:
 			self.searchEdit.setPlaceholderText(self.tr('Search'))
-		except:
-			pass
+		except: pass
 		self.connect(self.searchEdit, SIGNAL('returnPressed()'), self.find)
 		self.csBox = QCheckBox(self.tr('Case sensitively'), self.searchBar)
 		self.searchBar.addWidget(self.searchEdit)
@@ -509,7 +532,7 @@ class ReTextWindow(QMainWindow):
 		self.searchBar.setVisible(False)
 		self.autoSave = False
 		if settings.contains('autoSave'):
-			if settings.value('autoSave', type=bool):
+			if readFromSettings(settings, 'autoSave', bool):
 				self.autoSave = True
 				timer = QTimer(self)
 				timer.start(60000)
@@ -517,14 +540,27 @@ class ReTextWindow(QMainWindow):
 		self.restorePreviewState = False
 		self.livePreviewEnabled = False
 		if settings.contains('restorePreviewState'):
-			self.restorePreviewState = settings.value('restorePreviewState', type=bool)
+			self.restorePreviewState = readFromSettings(settings, 'restorePreviewState', bool)
 		if settings.contains('previewState'):
-			self.livePreviewEnabled = settings.value('previewState', type=bool)
+			self.livePreviewEnabled = readFromSettings(settings, 'previewState', bool)
 		self.ind = 0
 		self.tabWidget.addTab(self.createTab(""), self.tr('New document'))
+		self.highlighters[0].docType = self.getDocType()
+		if use_enchant:
+			self.sl = None
+			if settings.contains('spellCheckLocale'):
+				try:
+					self.sl = str(readFromSettings(settings, 'spellCheckLocale', str))
+					enchant.Dict(self.sl)
+				except Exception as e:
+					print(e)
+					self.sl = None
+			if settings.contains('spellCheck'):
+				if readFromSettings(settings, 'spellCheck', bool):
+					self.actionEnableSC.setChecked(True)
+					self.enableSC(True)
 		if not (use_md or use_docutils):
-			QMessageBox.warning(self, app_name, self.tr('You have neither Markdown nor Docutils modules installed!') \
-			+'<br>'+self.tr('Only HTML formatting will be available.'))
+			QMessageBox.warning(self, app_name, self.tr('You have neither Markdown nor Docutils modules installed!'))
 	
 	def act(self, name, icon=None, trig=None, trigbool=None, shct=None):
 		if icon:
@@ -562,11 +598,16 @@ class ReTextWindow(QMainWindow):
 		self.previewBlocked = False
 		self.editBoxes.append(QTextEdit())
 		self.highlighters.append(ReTextHighlighter(self.editBoxes[-1].document()))
+		if use_enchant and self.actionEnableSC.isChecked():
+			self.highlighters[-1].dictionary = \
+			enchant.Dict(self.sl) if self.sl else enchant.Dict()
+			self.highlighters[-1].rehighlight()
 		if self.useWebKit:
 			self.previewBoxes.append(QWebView())
 		else:
 			self.previewBoxes.append(QTextEdit())
 			self.previewBoxes[-1].setReadOnly(True)
+		self.editBoxes[-1].contextMenuEvent = self.editBoxMenuEvent
 		self.previewBoxes[-1].setVisible(False)
 		self.fileNames.append(fileName)
 		liveMode = self.restorePreviewState and self.livePreviewEnabled
@@ -583,6 +624,47 @@ class ReTextWindow(QMainWindow):
 		self.connect(self.editBoxes[-1].document(), SIGNAL('modificationChanged(bool)'), self.modificationChanged)
 		return self.getSplitter(-1)
 	
+	def editBoxMenuEvent(self, event):
+		editBox = self.editBoxes[self.ind]
+		text = editBox.toPlainText()
+		dictionary = self.highlighters[self.ind].dictionary
+		if dictionary is None or not text:
+			return QTextEdit.contextMenuEvent(editBox, event)
+		oldcursor = editBox.textCursor()
+		cursor = editBox.cursorForPosition(event.pos())
+		pos = cursor.positionInBlock()
+		if pos == len(text): pos -= 1
+		try:
+			curchar = text[pos]
+			isalpha = curchar.isalpha()
+		except AttributeError:
+			# For Python 2
+			curchar = text.at(pos)
+			isalpha = curchar.isLetter()
+		if not isalpha:
+			return QTextEdit.contextMenuEvent(editBox, event)
+		cursor.select(QTextCursor.WordUnderCursor)
+		editBox.setTextCursor(cursor)
+		word = cursor.selectedText()
+		try:
+			word = unicode(cursor.selectedText())
+		except NameError:
+			# Not needed for Python 3
+			word = cursor.selectedText()
+		if not word or dictionary.check(word):
+			editBox.setTextCursor(oldcursor)
+			return QTextEdit.contextMenuEvent(editBox, event)
+		suggestions = dictionary.suggest(word)
+		actions = [self.act(sug, trig=self.fixWord(sug)) for sug in suggestions]
+		menu = editBox.createStandardContextMenu()
+		menu.insertSeparator(menu.actions()[0])
+		for action in actions[::-1]:
+			menu.insertAction(menu.actions()[0], action) 
+		menu.exec_(event.globalPos())
+	
+	def fixWord(self, correctword):
+		return lambda: self.editBoxes[self.ind].insertPlainText(correctword)
+	
 	def closeTab(self, ind):
 		if self.maybeSave(ind):
 			if self.tabWidget.count() == 1:
@@ -597,10 +679,34 @@ class ReTextWindow(QMainWindow):
 			del self.gDocsEntries[ind]
 			self.tabWidget.removeTab(ind)
 	
+	def getDocType(self):
+		if self.aptc[self.ind]:
+			return DOCTYPE_PLAINTEXT
+		if self.fileNames[self.ind]:
+			suffix = QFileInfo(self.fileNames[self.ind]).suffix()
+			if suffix in ('md', 'markdown', 'mdown', 'mkd', 'mkdn', 're'):
+				return DOCTYPE_MARKDOWN
+			elif suffix in ('rest', 'rst'):
+				return DOCTYPE_REST
+		return self.defaultDocType
+	
+	def docTypeChanged(self):
+		oldType = self.highlighters[self.ind].docType
+		newType = self.getDocType()
+		if oldType != newType:
+			self.updatePreviewBox()
+			self.highlighters[self.ind].docType = newType
+			self.highlighters[self.ind].rehighlight()
+		dtMarkdown = (newType == DOCTYPE_MARKDOWN)
+		self.tagsBox.setEnabled(dtMarkdown)
+		self.symbolBox.setEnabled(dtMarkdown)
+		self.actionUnderline.setEnabled(dtMarkdown)
+	
 	def changeIndex(self, ind):
 		if ind > -1:
 			self.actionPlainText.setChecked(self.aptc[ind])
-			self.enablePlainTextMain(self.aptc[ind])
+			self.actionPerfectHtml.setDisabled(self.aptc[ind])
+			self.actionViewHtml.setDisabled(self.aptc[ind])
 			self.actionUndo.setEnabled(self.editBoxes[ind].document().isUndoAvailable())
 			self.actionRedo.setEnabled(self.editBoxes[ind].document().isRedoAvailable())
 			self.actionCopy.setEnabled(self.editBoxes[ind].textCursor().hasSelection())
@@ -617,6 +723,7 @@ class ReTextWindow(QMainWindow):
 			except:
 				# For Python 3
 				self.setWindowTitle(self.tr('New document') + '[*] \u2014 ' + app_name)
+			self.docTypeChanged()
 		self.modificationChanged(self.editBoxes[ind].document().isModified())
 		self.livePreviewEnabled = self.alpc[ind]
 		if self.alpc[ind]:
@@ -649,6 +756,7 @@ class ReTextWindow(QMainWindow):
 	def enableLivePreview(self, livemode):
 		self.livePreviewEnabled = livemode
 		self.alpc[self.ind] = livemode
+		self.apc[self.ind] = livemode
 		self.actionPreview.setChecked(livemode)
 		self.editBar.setEnabled(True)
 		self.previewBoxes[self.ind].setVisible(livemode)
@@ -673,7 +781,6 @@ class ReTextWindow(QMainWindow):
 			splitter = self.getSplitter(self.ind)
 			self.tabWidget.addTab(splitter, self.getDocumentTitle(baseName=True))
 			self.updatePreviewBox()
-			self.editBoxes[self.ind].setVisible(self.alpc[self.ind] or not self.apc[self.ind])
 			self.previewBoxes[self.ind].setVisible(self.apc[self.ind])
 		self.ind = oldind
 		self.tabWidget.setCurrentIndex(self.ind)
@@ -688,35 +795,21 @@ class ReTextWindow(QMainWindow):
 		else:
 			self.showNormal()
 	
-	def keyPressEvent(self, e):
-		v = not self.menubar.isVisible()
-		if e.key() == Qt.Key_F12 and e.modifiers() & Qt.ShiftModifier:
-			self.menubar.setVisible(v)
-			self.toolBar.setVisible(v)
-			self.editBar.setVisible(v)
-		elif e.key() == Qt.Key_F11:
-			if v:
-				n = not self.actionFullScreen.isChecked()
-				self.actionFullScreen.setChecked(n)
-				self.enableFullScreen(n)
-	
 	def enableSC(self, yes):
-		global dictionary
 		if yes:
 			if self.sl:
-				try:
-					dictionary = enchant.Dict(self.sl)
-				except Exception as e:
-					QMessageBox.warning(self, app_name, str(e))
-					dictionary = enchant.Dict()
+				self.setAllDictionaries(enchant.Dict(self.sl))
 			else:
-				dictionary = enchant.Dict()
+				self.setAllDictionaries(enchant.Dict())
 			settings.setValue('spellCheck', True)
 		else:
-			dictionary = None
+			self.setAllDictionaries(None)
 			settings.remove('spellCheck')
-		for highlighter in self.highlighters:
-			highlighter.rehighlight()
+	
+	def setAllDictionaries(self, dictionary):
+		for hl in self.highlighters:
+			hl.dictionary = dictionary
+			hl.rehighlight()
 	
 	def changeLocale(self):
 		if self.sl == None:
@@ -727,8 +820,9 @@ class ReTextWindow(QMainWindow):
 		if ok and sl:
 			try:
 				sl = str(sl)
-			except:
-				pass
+				enchant.Dict(sl)
+			except Exception as e:
+				QMessageBox.warning(self, app_name, str(e))
 			else:
 				self.sl = sl
 				self.enableSC(self.actionEnableSC.isChecked())
@@ -770,7 +864,7 @@ class ReTextWindow(QMainWindow):
 		textedit = isinstance(pb, QTextEdit)
 		if self.ss and textedit:
 			pb.document().setDefaultStyleSheet(self.ss)
-		if self.actionPlainText.isChecked():
+		if self.getDocType() == DOCTYPE_PLAINTEXT:
 			if textedit:
 				pb.setPlainText(self.editBoxes[self.ind].toPlainText())
 			else:
@@ -779,9 +873,18 @@ class ReTextWindow(QMainWindow):
 				pb.setHtml(td.toHtml())
 		else:
 			try:
-				pb.setHtml(self.parseText())
+				parsedText = self.parseText()
 			except Exception as e:
 				self.printError(e)
+			else:
+				if textedit:
+					pb.setHtml(parsedText)
+				else:
+					size = (self.font if self.font else QFont()).pointSize()
+					pb.setHtml(
+					'<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">' +\
+					'<html><body style="font-family: Sans; font-size: %spt">\n' % size +\
+					parsedText + '</body></html>\n')
 		if self.font and textedit:
 			pb.document().setDefaultFont(self.font)
 	
@@ -795,8 +898,8 @@ class ReTextWindow(QMainWindow):
 			QMessageBox.warning(self, app_name, self.tr("Please, save the file somewhere."))
 		elif wpgen:
 			if not (QDir("html").exists() and QFile.exists("template.html")):
-				subprocess.Popen((wpgen, 'init')).wait()
-			subprocess.Popen([wpgen, 'updateall']).wait()
+				Popen((wpgen, 'init')).wait()
+			Popen([wpgen, 'updateall']).wait()
 			msgBox = QMessageBox(QMessageBox.Information, app_name, \
 			self.tr("Webpages saved in <code>html</code> directory."), QMessageBox.Ok)
 			showButton = msgBox.addButton(self.tr("Show directory"), QMessageBox.AcceptRole)
@@ -829,6 +932,7 @@ class ReTextWindow(QMainWindow):
 			del files[10:]
 		writeListToSettings(settings, "recentFileList", files)
 		QDir.setCurrent(QFileInfo(self.fileNames[self.ind]).dir().path())
+		self.docTypeChanged()
 	
 	def createNew(self):
 		self.tabWidget.addTab(self.createTab(""), self.tr("New document"))
@@ -890,19 +994,18 @@ class ReTextWindow(QMainWindow):
 				self.extensionActions.append((action, mimetype))
 	
 	def updateExtensionsVisibility(self):
+		docType = self.getDocType()
 		for action in self.extensionActions:
-			if self.actionPlainText.isChecked():
+			if docType == DOCTYPE_PLAINTEXT:
 				action[0].setEnabled(False)
 				continue
 			mimetype = action[1]
 			if mimetype == None:
 				enabled = True
-			elif self.getParser() == PARSER_MARKDOWN:
+			elif docType == DOCTYPE_MARKDOWN:
 				enabled = (mimetype in ("text/x-retext-markdown", "text/x-markdown"))
-			elif self.getParser() == PARSER_DOCUTILS:
+			elif docType == DOCTYPE_REST:
 				enabled = (mimetype in ("text/x-retext-rst", "text/x-rst"))
-			elif self.getParser() == PARSER_HTML:
-				enabled = (mimetype == "text/html")
 			else:
 				enabled = False
 			action[0].setEnabled(enabled)
@@ -927,13 +1030,14 @@ class ReTextWindow(QMainWindow):
 	
 	def openFile(self):
 		fileNames = QFileDialog.getOpenFileNames(self, self.tr("Select one or several files to open"), "", \
-		self.tr("Supported files")+" (*.re *.md *.markdown *.mdown *.mkd *.mkdn *.rst *.rest *.txt *.html *.htm);;"+self.tr("All files (*)"))
+		self.tr("Supported files")+" (*.re *.md *.markdown *.mdown *.mkd *.mkdn *.rst *.rest *.txt);;"+self.tr("All files (*)"))
 		for fileName in fileNames:
 			self.openFileWrapper(fileName)
 	
 	def openFileWrapper(self, fileName):
 		if not fileName:
 			return
+		fileName = QFileInfo(fileName).canonicalFilePath()
 		exists = False
 		for i in range(self.tabWidget.count()):
 			if self.fileNames[i] == fileName:
@@ -941,7 +1045,7 @@ class ReTextWindow(QMainWindow):
 				ex = i
 		if exists:
 			self.tabWidget.setCurrentIndex(ex)
-		else:
+		elif QFile.exists(fileName):
 			if self.fileNames[self.ind] or self.editBoxes[self.ind].toPlainText() \
 			or self.editBoxes[self.ind].document().isModified():
 				self.tabWidget.addTab(self.createTab(""), "")
@@ -951,18 +1055,20 @@ class ReTextWindow(QMainWindow):
 			self.openFileMain()
 	
 	def openFileMain(self):
-		if QFile.exists(self.fileNames[self.ind]):
-			openfile = QFile(self.fileNames[self.ind])
-			openfile.open(QIODevice.ReadOnly)
-			html = QTextStream(openfile).readAll()
-			openfile.close()
-			self.editBoxes[self.ind].setPlainText(html)
-			suffix = QFileInfo(self.fileNames[self.ind]).suffix()
-			pt = not (suffix in ('re', 'md', 'markdown', 'mdown', 'mkd', 'mkdn', 'rst', 'rest', 'html', 'htm'))
-			self.actionPlainText.setChecked(pt)
-			self.enablePlainText(pt)
-			self.setCurrentFile()
-			self.setWindowModified(False)
+		openfile = QFile(self.fileNames[self.ind])
+		openfile.open(QIODevice.ReadOnly)
+		html = QTextStream(openfile).readAll()
+		openfile.close()
+		self.editBoxes[self.ind].setPlainText(html)
+		suffix = QFileInfo(self.fileNames[self.ind]).suffix()
+		pt = suffix not in ('re', 'md', 'markdown', 'mdown', 'mkd', 'mkdn', 'rst', 'rest')
+		if settings.contains('autoPlainText'):
+			if not readFromSettings(settings, 'autoPlainText', bool):
+				pt = False
+		self.actionPlainText.setChecked(pt)
+		self.enablePlainText(pt)
+		self.setCurrentFile()
+		self.setWindowModified(False)
 	
 	def saveFile(self):
 		self.saveFileMain(dlg=False)
@@ -974,45 +1080,46 @@ class ReTextWindow(QMainWindow):
 		oldind = self.ind
 		for self.ind in range(self.tabWidget.count()):
 			if self.fileNames[self.ind] and QFileInfo(self.fileNames[self.ind]).isWritable():
-				self.saveFileWrapper(self.fileNames[self.ind])
+				self.saveFileCore(self.fileNames[self.ind])
 				self.editBoxes[self.ind].document().setModified(False)
 		self.ind = oldind
 	
 	def saveFileMain(self, dlg):
 		if (not self.fileNames[self.ind]) or dlg:
-			if self.actionPlainText.isChecked():
+			docType = self.getDocType()
+			if docType == DOCTYPE_PLAINTEXT:
 				defaultExt = self.tr("Plain text (*.txt)")
 				ext = ".txt"
-			elif self.getParser() == PARSER_DOCUTILS:
+			elif docType == DOCTYPE_REST:
 				defaultExt = self.tr("ReStructuredText files")+" (*.rest *.rst *.txt)"
 				ext = ".rst"
-			elif self.getParser() == PARSER_HTML:
-				defaultExt = self.tr("HTML files")+" (*.html *.htm)"
-				ext = ".html"
 			else:
 				defaultExt = self.tr("Markdown files")+" (*.re *.md *.markdown *.mdown *.mkd *.mkdn *.txt)"
 				ext = ".mkd"
 				if settings.contains('defaultExt'):
-					ext = settings.value('defaultExt', type='QString')
+					ext = readFromSettings(settings, 'defaultExt', str)
 			self.fileNames[self.ind] = QFileDialog.getSaveFileName(self, self.tr("Save file"), "", defaultExt)
 			if self.fileNames[self.ind] and not QFileInfo(self.fileNames[self.ind]).suffix():
 				self.fileNames[self.ind] += ext
-		if QFileInfo(self.fileNames[self.ind]).isWritable() or not QFile.exists(self.fileNames[self.ind]):
-			if self.fileNames[self.ind]:
-				self.saveFileWrapper(self.fileNames[self.ind])
+		if self.fileNames[self.ind]:
+			result = self.saveFileCore(self.fileNames[self.ind])
+			if result:
 				self.setCurrentFile()
 				self.editBoxes[self.ind].document().setModified(False)
 				self.setWindowModified(False)
-		else:
-			self.setWindowModified(self.isWindowModified())
-			QMessageBox.warning(self, app_name, self.tr("Cannot save to file because it is read-only!"))
+				return True
+			else:
+				QMessageBox.warning(self, app_name, self.tr("Cannot save to file because it is read-only!"))
+		return False
 	
-	def saveFileWrapper(self, fn):
+	def saveFileCore(self, fn):
 		savefile = QFile(fn)
-		savefile.open(QIODevice.WriteOnly)
-		savestream = QTextStream(savefile)
-		savestream << self.editBoxes[self.ind].toPlainText()
-		savefile.close()
+		result = savefile.open(QIODevice.WriteOnly)
+		if result:
+			savestream = QTextStream(savefile)
+			savestream << self.editBoxes[self.ind].toPlainText()
+			savefile.close()
+		return result
 	
 	def saveHtml(self, fileName):
 		if not QFileInfo(fileName).suffix():
@@ -1024,13 +1131,9 @@ class ReTextWindow(QMainWindow):
 		htmlFile = QFile(fileName)
 		htmlFile.open(QIODevice.WriteOnly)
 		html = QTextStream(htmlFile)
-		if self.getParser() == PARSER_HTML:
-			html << text << "\n"
-			htmlFile.close()
-			return
 		html << '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">\n'
 		html << '<html>\n<head>\n'
-		html << '  <meta http-equiv="content-type" content="text/html; charset="utf-8">\n'
+		html << '  <meta http-equiv="content-type" content="text/html; charset=utf-8">\n'
 		html << '  <meta name="generator" content="%s %s">\n' % (app_name, app_version)
 		html << '  <title>' + self.getDocumentTitle() + '</title>\n'
 		html << '</head>\n<body>\n'
@@ -1039,13 +1142,13 @@ class ReTextWindow(QMainWindow):
 		htmlFile.close()
 	
 	def textDocument(self):
-		if not self.actionPlainText.isChecked():
-			text = self.parseText()
+		plainText = (self.getDocType == DOCTYPE_PLAINTEXT)
+		if not plainText: text = self.parseText()
 		td = QTextDocument()
 		td.setMetaInformation(QTextDocument.DocumentTitle, self.getDocumentTitle())
 		if self.ss:
 			td.setDefaultStyleSheet(self.ss)
-		if self.actionPlainText.isChecked():
+		if plainText:
 			td.setPlainText(self.editBoxes[self.ind].toPlainText())
 		else:
 			td.setHtml('<html><body>'+text+'</body></html>')
@@ -1119,7 +1222,7 @@ class ReTextWindow(QMainWindow):
 		self.connect(preview, SIGNAL("paintRequested(QPrinter*)"), document.print_)
 		preview.exec_()
 	
-	def runExtensionCommand(self, command, filefilter='', defaultext=''):
+	def runExtensionCommand(self, command, filefilter, defaultext):
 		of = ('%of' in command)
 		html = ('%html' in command)
 		if of:
@@ -1134,13 +1237,14 @@ class ReTextWindow(QMainWindow):
 			tmpname = '.retext-temp.html'
 			self.saveHtml(tmpname)
 		else:
-			tmpname = '.retext-temp.rst' if self.getParser() == PARSER_DOCUTILS else '.retext-temp.mkd'
-			self.saveFileWrapper(tmpname)
+			if self.getDocType() == DOCTYPE_REST: tmpname = '.retext-temp.rst'
+			else: tmpname = '.retext-temp.mkd'
+			self.saveFileCore(tmpname)
 		command = command.replace('%of', 'out'+defaultext)
 		command = command.replace('%html' if html else '%if', tmpname)
 		args = str(command).split()
 		try:
-			subprocess.Popen(args).wait()
+			Popen(args).wait()
 		except Exception as error:
 			errorstr = str(error)
 			try:
@@ -1153,18 +1257,6 @@ class ReTextWindow(QMainWindow):
 		if of:
 			QFile('out'+defaultext).rename(fileName)
 	
-	def otherExport(self):
-		if self.actionPlainText.isChecked():
-			return QMessageBox.warning(self, app_name, self.tr('This function is not available in Plain text mode!'))
-		settings.beginGroup('Export')
-		types = settings.allKeys()
-		item, ok = QInputDialog.getItem(self, app_name, self.tr('Select type'), types, 0, False)
-		if not ok:
-			return settings.endGroup()
-		command = settings.value(item, type='QString')
-		settings.endGroup()
-		self.runExtensionCommand(command, defaultext='.'+item)
-	
 	def getDocumentTitle(self, baseName=False):
 		"""Ensure that parseText() is called before this function!
 		If 'baseName' is set to True, file basename will be used."""
@@ -1174,28 +1266,28 @@ class ReTextWindow(QMainWindow):
 		except:
 			# For Python 3
 			text = self.editBoxes[self.ind].toPlainText()
-		if not self.actionPlainText.isChecked():
-			parser = self.getParser()
-			if parser == PARSER_DOCUTILS:
-				realTitle = publish_parts(text, writer_name='html')['title']
-			elif parser == PARSER_MARKDOWN:
-				try:
-					realTitle = str.join(' ', md.Meta['title'])
-				except:
-					# Meta extension not installed
-					pass
+		docType = self.getDocType()
+		if docType == DOCTYPE_REST:
+			realTitle = publish_parts(text, writer_name='html')['title']
+		elif docType == DOCTYPE_MARKDOWN:
+			try:
+				realTitle = str.join(' ', md.Meta['title'])
+			except:
+				# Meta extension not installed
+				pass
 		if realTitle and not baseName:
 			return realTitle
 		elif self.fileNames[self.ind]:
 			fileinfo = QFileInfo(self.fileNames[self.ind])
 			basename = fileinfo.completeBaseName()
 			return (basename if basename else fileinfo.fileName())
-		else:
-			return self.tr("New document")
+		return self.tr("New document")
 	
 	def saveGDocs(self):
-		login = settings.value("GDocsLogin", type='QString')
-		passwd = settings.value("GDocsPasswd", type='QString')
+		login = passwd = ''
+		if settings.contains('GDocsLogin') and settings.contains('GDocsPasswd'):
+			login = readFromSettings(settings, 'GDocsLogin', str)
+			passwd = readFromSettings(settings, 'GDocsPasswd', str)
 		if self.gDocsEntries[self.ind] == None:
 			loginDialog = LogPassDialog(login, passwd)
 			if loginDialog.exec_() == QDialog.Accepted:
@@ -1203,10 +1295,10 @@ class ReTextWindow(QMainWindow):
 				passwd = loginDialog.passEdit.text()
 			else:
 				return
-		if self.actionPlainText.isChecked():
+		if self.getDocType() == DOCTYPE_PLAINTEXT:
 			tempFile = '.retext-temp.txt'
 			contentType = 'text/plain'
-			self.saveFileWrapper(tempFile)
+			self.saveFileCore(tempFile)
 		else:
 			tempFile = '.retext-temp.html'
 			contentType = 'text/html'
@@ -1264,24 +1356,28 @@ class ReTextWindow(QMainWindow):
 	
 	def insertChars(self, chars):
 		tc = self.editBoxes[self.ind].textCursor()
-		if tc.hasSelection:
-			tc.insertText(chars+tc.selectedText()+chars)
+		if tc.hasSelection():
+			try:
+				selection = unicode(tc.selectedText())
+			except:
+				# For Python 3
+				selection = tc.selectedText()
+			if selection.startswith(chars) and selection.endswith(chars):
+				if len(selection) > 2*len(chars):
+					selection = selection[len(chars):-len(chars)]
+					tc.insertText(selection)
+			else:
+				tc.insertText(chars+tc.selectedText()+chars)
 		else:
 			tc.insertText(chars)
 	
 	def insertTag(self, num):
 		if num:
 			ut = self.usefulTags[num-1]
-			hc = not ut in ('td', 'tr')
-			arg = ''
-			if ut == 'span':
-				arg = ' style=""'
+			arg = ' style=""' if ut == 'span' else '' 
 			tc = self.editBoxes[self.ind].textCursor()
-			if hc:
-				toinsert = '<'+ut+arg+'>'+tc.selectedText()+'</'+ut+'>'
-				tc.insertText(toinsert)
-			else:
-				tc.insertText('<'+ut+arg+'>'+tc.selectedText())
+			toinsert = '<'+ut+arg+'>'+tc.selectedText()+'</'+ut+'>'
+			tc.insertText(toinsert)
 		self.tagsBox.setCurrentIndex(0)
 	
 	def insertSymbol(self, num):
@@ -1291,7 +1387,7 @@ class ReTextWindow(QMainWindow):
 	
 	def maybeSave(self, ind):
 		if self.autoSaveActive():
-			self.saveFileWrapper(self.fileNames[self.ind])
+			self.saveFileCore(self.fileNames[self.ind])
 			return True
 		if not self.editBoxes[ind].document().isModified():
 			return True
@@ -1299,26 +1395,21 @@ class ReTextWindow(QMainWindow):
 		ret = QMessageBox.warning(self, app_name, self.tr("The document has been modified.\nDo you want to save your changes?"), \
 		QMessageBox.Save | QMessageBox.Discard | QMessageBox.Cancel)
 		if ret == QMessageBox.Save:
-			self.saveFileMain(False)
-			return True
+			return self.saveFileMain(False)
 		elif ret == QMessageBox.Cancel:
 			return False
 		return True
 	
 	def closeEvent(self, closeevent):
-		accept = True
 		for self.ind in range(self.tabWidget.count()):
 			if not self.maybeSave(self.ind):
-				accept = False
-		if accept:
-			if self.restorePreviewState:
-				if self.livePreviewEnabled:
-					settings.setValue('previewState', True)
-				else:
-					settings.remove('previewState')
-			closeevent.accept()
-		else:
-			closeevent.ignore()
+				return closeevent.ignore()
+		if self.restorePreviewState:
+			if self.livePreviewEnabled:
+				settings.setValue('previewState', True)
+			else:
+				settings.remove('previewState')
+		closeevent.accept()
 	
 	def viewHtml(self):
 		HtmlDlg = HtmlDialog(self)
@@ -1353,41 +1444,29 @@ class ReTextWindow(QMainWindow):
 	
 	def enablePlainText(self, value):
 		self.aptc[self.ind] = value
-		self.enablePlainTextMain(value)
-		self.updatePreviewBox()
-	
-	def enablePlainTextMain(self, value):
 		self.actionPerfectHtml.setDisabled(value)
 		self.actionViewHtml.setDisabled(value)
-		self.tagsBox.setDisabled(value)
-		self.symbolBox.setDisabled(value)
+		self.updatePreviewBox()
+		self.docTypeChanged()
 	
 	def setDocUtilsDefault(self, yes):
-		self.useDocUtils = yes
-		settings.setValue('useReST', yes)
-		self.updatePreviewBox()
+		self.defaultDocType = DOCTYPE_REST if yes else DOCTYPE_MARKDOWN
+		if yes:
+			settings.setValue('useReST', True)
+		else:
+			settings.remove('useReST')
+		oldind = self.ind
+		for self.ind in range(len(self.previewBoxes)):
+			self.docTypeChanged()
+		self.ind = oldind
 	
 	def getParser(self):
-		if self.fileNames[self.ind]:
-			suffix = QFileInfo(self.fileNames[self.ind]).suffix()
-			if suffix in ('md', 'markdown', 'mdown', 'mkd', 'mkdn', 're'):
-				if use_md:
-					return PARSER_MARKDOWN
-				else:
-					return PARSER_NA
-			elif suffix in ('rest', 'rst'):
-				if use_docutils:
-					return PARSER_DOCUTILS
-				else:
-					return PARSER_NA
-			elif suffix in ('html', 'htm'):
-				return PARSER_HTML
-		if not (use_docutils or use_md):
-			return PARSER_HTML
-		elif use_docutils and (self.useDocUtils or not use_md):
-			return PARSER_DOCUTILS
-		else:
-			return PARSER_MARKDOWN
+		docType = self.getDocType()
+		if docType == DOCTYPE_MARKDOWN:
+			return PARSER_MARKDOWN if use_md else PARSER_NA
+		if docType == DOCTYPE_REST:
+			return PARSER_DOCUTILS if use_docutils else PARSER_NA
+		return PARSER_NA
 	
 	def parseText(self):
 		try:
@@ -1399,9 +1478,7 @@ class ReTextWindow(QMainWindow):
 		htmltext = htmltext.replace('%HTMLDIR%', 'html')
 		htmltext = htmltext.replace('%\\', '%')
 		parser = self.getParser()
-		if parser == PARSER_HTML:
-			return htmltext
-		elif parser == PARSER_DOCUTILS:
+		if parser == PARSER_DOCUTILS:
 			return publish_parts(htmltext, writer_name='html')['body']
 		elif parser == PARSER_MARKDOWN:
 			md.reset()
@@ -1423,7 +1500,7 @@ def main(fileNames):
 	app.installTranslator(RtTranslator)
 	app.installTranslator(QtTranslator)
 	if settings.contains('appStyleSheet'):
-		stylename = settings.value('appStyleSheet', type='QString')
+		stylename = readFromSettings(settings, 'appStyleSheet', str)
 		sheetfile = QFile(stylename)
 		sheetfile.open(QIODevice.ReadOnly)
 		app.setStyleSheet(QTextStream(sheetfile).readAll())
@@ -1441,7 +1518,4 @@ def main(fileNames):
 	sys.exit(app.exec_())
 
 if __name__ == '__main__':
-	if len(sys.argv) > 1:
-		main(sys.argv[1:])
-	else:
-		main("")
+	main(sys.argv[1:])
