@@ -3,17 +3,17 @@
 <context>
     <name>LogPassDialog</name>
     <message>
-        <location filename="retext.py" line="175"/>
+        <location filename="retext.py" line="208"/>
         <source>Enter your Google account data</source>
         <translation>Entrez vos données du compte Google</translation>
     </message>
     <message>
-        <location filename="retext.py" line="184"/>
+        <location filename="retext.py" line="217"/>
         <source>Username</source>
         <translation>Utilisateur</translation>
     </message>
     <message>
-        <location filename="retext.py" line="185"/>
+        <location filename="retext.py" line="218"/>
         <source>Password</source>
         <translation>Mot de passe</translation>
     </message>
@@ -21,439 +21,414 @@
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="retext.py" line="1330"/>
+        <location filename="retext.py" line="1421"/>
         <source>New document</source>
         <translation>Nouveau document</translation>
     </message>
     <message>
-        <location filename="retext.py" line="245"/>
+        <location filename="retext.py" line="287"/>
         <source>File toolbar</source>
         <translation>Barre d&apos;outil Fichier</translation>
     </message>
     <message>
-        <location filename="retext.py" line="247"/>
+        <location filename="retext.py" line="289"/>
         <source>Edit toolbar</source>
         <translation>Barre d&apos;outil Édition</translation>
     </message>
     <message>
-        <location filename="retext.py" line="249"/>
+        <location filename="retext.py" line="291"/>
         <source>Search toolbar</source>
         <translation>Barre d&apos;outil Rechercher</translation>
     </message>
     <message>
-        <location filename="retext.py" line="251"/>
+        <location filename="retext.py" line="293"/>
         <source>New</source>
         <translation>Nouveau</translation>
     </message>
     <message>
-        <location filename="retext.py" line="253"/>
+        <location filename="retext.py" line="295"/>
         <source>Open</source>
         <translation>Ouvrir</translation>
     </message>
     <message>
-        <location filename="retext.py" line="255"/>
+        <location filename="retext.py" line="297"/>
         <source>Save</source>
         <translation>Enregistrer</translation>
     </message>
     <message>
-        <location filename="retext.py" line="258"/>
+        <location filename="retext.py" line="300"/>
         <source>Save as</source>
         <translation>Enregistrer Sous</translation>
     </message>
     <message>
-        <location filename="retext.py" line="260"/>
+        <location filename="retext.py" line="302"/>
         <source>Print</source>
         <translation>Imprimer</translation>
     </message>
     <message>
-        <location filename="retext.py" line="262"/>
+        <location filename="retext.py" line="304"/>
         <source>Print preview</source>
         <translation>Aperçu d&apos;impression</translation>
     </message>
     <message>
-        <location filename="retext.py" line="264"/>
+        <location filename="retext.py" line="306"/>
         <source>View HTML code</source>
         <translation>Voir code HTML</translation>
     </message>
     <message>
-        <location filename="retext.py" line="265"/>
+        <location filename="retext.py" line="307"/>
         <source>Change default font</source>
         <translation>Changer police par défaut</translation>
     </message>
     <message>
-        <location filename="retext.py" line="266"/>
+        <location filename="retext.py" line="308"/>
         <source>Find text</source>
         <translation>Chercher text</translation>
     </message>
     <message>
-        <location filename="retext.py" line="270"/>
+        <location filename="retext.py" line="312"/>
         <source>Preview</source>
         <translation>Aperçu</translation>
     </message>
     <message>
-        <location filename="retext.py" line="279"/>
+        <location filename="retext.py" line="321"/>
         <source>Live preview</source>
         <translation>Aperçu live</translation>
     </message>
     <message>
-        <location filename="retext.py" line="281"/>
+        <location filename="retext.py" line="323"/>
         <source>Fullscreen mode</source>
         <translation>Mode plein écran</translation>
     </message>
     <message>
-        <location filename="retext.py" line="288"/>
-        <source>Other formats</source>
-        <translation>Autres formats</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="294"/>
+        <location filename="retext.py" line="329"/>
         <source>Quit</source>
         <translation>Quitter</translation>
     </message>
     <message>
-        <location filename="retext.py" line="297"/>
+        <location filename="retext.py" line="332"/>
         <source>Undo</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="retext.py" line="299"/>
+        <location filename="retext.py" line="334"/>
         <source>Redo</source>
         <translation>Rétablir</translation>
     </message>
     <message>
-        <location filename="retext.py" line="301"/>
+        <location filename="retext.py" line="336"/>
         <source>Copy</source>
         <translation>Copier</translation>
     </message>
     <message>
-        <location filename="retext.py" line="303"/>
+        <location filename="retext.py" line="338"/>
         <source>Cut</source>
         <translation>Couper</translation>
     </message>
     <message>
-        <location filename="retext.py" line="305"/>
+        <location filename="retext.py" line="340"/>
         <source>Paste</source>
         <translation>Coller</translation>
     </message>
     <message>
-        <location filename="retext.py" line="315"/>
+        <location filename="retext.py" line="349"/>
         <source>Enable</source>
         <translation>Activer</translation>
     </message>
     <message>
-        <location filename="retext.py" line="316"/>
+        <location filename="retext.py" line="350"/>
         <source>Set locale</source>
         <translation>choisir langue</translation>
     </message>
     <message>
-        <location filename="retext.py" line="325"/>
+        <location filename="retext.py" line="351"/>
         <source>Plain text</source>
         <translation>Format Text</translation>
     </message>
     <message>
-        <location filename="retext.py" line="413"/>
+        <location filename="retext.py" line="438"/>
         <source>Open recent</source>
         <translation>Ouvrir récent</translation>
     </message>
     <message>
-        <location filename="retext.py" line="334"/>
+        <location filename="retext.py" line="360"/>
         <source>Generate webpages</source>
         <translation>Générer pages web</translation>
     </message>
     <message>
-        <location filename="retext.py" line="335"/>
+        <location filename="retext.py" line="361"/>
         <source>Show</source>
         <translation>Montrer</translation>
     </message>
     <message>
-        <location filename="retext.py" line="336"/>
+        <location filename="retext.py" line="362"/>
         <source>Next</source>
         <translation>Suivant</translation>
     </message>
     <message>
-        <location filename="retext.py" line="337"/>
+        <location filename="retext.py" line="363"/>
         <source>Previous</source>
         <translation>Précédent</translation>
     </message>
     <message>
-        <location filename="retext.py" line="339"/>
+        <location filename="retext.py" line="365"/>
         <source>Get help online</source>
         <translation>Aide en ligne</translation>
     </message>
     <message>
-        <location filename="retext.py" line="347"/>
+        <location filename="retext.py" line="373"/>
         <source>About Qt</source>
         <translation>À propos de Qt</translation>
     </message>
     <message>
-        <location filename="retext.py" line="373"/>
+        <location filename="retext.py" line="399"/>
         <source>Save to Google Docs</source>
         <translation>Enregistrer sur Google Docs</translation>
     </message>
     <message>
-        <location filename="retext.py" line="380"/>
+        <location filename="retext.py" line="406"/>
         <source>Tags</source>
         <translation>Tags</translation>
     </message>
     <message>
-        <location filename="retext.py" line="384"/>
+        <location filename="retext.py" line="410"/>
         <source>Symbols</source>
         <translation>Symboles</translation>
     </message>
     <message>
-        <location filename="retext.py" line="408"/>
+        <location filename="retext.py" line="433"/>
         <source>File</source>
         <translation>Fichier</translation>
     </message>
     <message>
-        <location filename="retext.py" line="409"/>
+        <location filename="retext.py" line="434"/>
         <source>Edit</source>
         <translation>Édition</translation>
     </message>
     <message>
-        <location filename="retext.py" line="410"/>
+        <location filename="retext.py" line="435"/>
         <source>Help</source>
         <translation>Aide</translation>
     </message>
     <message>
-        <location filename="retext.py" line="416"/>
+        <location filename="retext.py" line="441"/>
         <source>Directory</source>
         <translation>Répertoire</translation>
     </message>
     <message>
-        <location filename="retext.py" line="424"/>
+        <location filename="retext.py" line="449"/>
         <source>Export</source>
         <translation>Exporter</translation>
     </message>
     <message>
-        <location filename="retext.py" line="450"/>
+        <location filename="retext.py" line="474"/>
         <source>Spell check</source>
         <translation>Vérificateur</translation>
     </message>
     <message>
-        <location filename="retext.py" line="458"/>
+        <location filename="retext.py" line="482"/>
         <source>Default editing mode</source>
         <translation>Mode d&apos;édition par défaut</translation>
     </message>
     <message>
-        <location filename="retext.py" line="499"/>
+        <location filename="retext.py" line="523"/>
         <source>Search</source>
         <translation>Chercher</translation>
     </message>
     <message>
-        <location filename="retext.py" line="503"/>
+        <location filename="retext.py" line="526"/>
         <source>Case sensitively</source>
         <translation>Respect de la casse</translation>
     </message>
     <message>
-        <location filename="retext.py" line="526"/>
+        <location filename="retext.py" line="563"/>
         <source>You have neither Markdown nor Docutils modules installed!</source>
         <translation>Vous n&apos;avez pas Markdown, ni Docutils d&apos;installé !</translation>
     </message>
     <message>
-        <location filename="retext.py" line="526"/>
-        <source>Only HTML formatting will be available.</source>
-        <translation>Seulement le format HTML sera disponible.</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="726"/>
+        <location filename="retext.py" line="819"/>
         <source>Enter locale name (example: en_US)</source>
         <translation>Entrez le préfix pour la lagnue (exemple: fr_FR)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="813"/>
+        <location filename="retext.py" line="916"/>
         <source>Please, save the file somewhere.</source>
         <translation>SVP, enregistrer le fichier quelque part.</translation>
     </message>
     <message>
-        <location filename="retext.py" line="800"/>
+        <location filename="retext.py" line="903"/>
         <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
         <translation>Pages enregistrés dans le répertoire &lt;code&gt;html&lt;/code&gt;.</translation>
     </message>
     <message>
-        <location filename="retext.py" line="929"/>
+        <location filename="retext.py" line="1032"/>
         <source>Select one or several files to open</source>
         <translation>choisir un ou plusieurs fichiers pour ouvrir</translation>
     </message>
     <message>
-        <location filename="retext.py" line="929"/>
+        <location filename="retext.py" line="1032"/>
         <source>Supported files</source>
         <translation>Formats supportés</translation>
     </message>
     <message>
-        <location filename="retext.py" line="929"/>
+        <location filename="retext.py" line="1032"/>
         <source>All files (*)</source>
         <translation>Tous fichiers (*)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="984"/>
+        <location filename="retext.py" line="1091"/>
         <source>Plain text (*.txt)</source>
         <translation>Fichier text (*.txt)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="987"/>
+        <location filename="retext.py" line="1094"/>
         <source>ReStructuredText files</source>
         <translation>Fichiers ReStructuredText</translation>
     </message>
     <message>
-        <location filename="retext.py" line="990"/>
-        <source>HTML files</source>
-        <translation>Fichiers HTML</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="993"/>
+        <location filename="retext.py" line="1097"/>
         <source>Markdown files</source>
         <translation>Fichiers Markdown</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1071"/>
+        <location filename="retext.py" line="1174"/>
         <source>Save file</source>
         <translation>Enregistrer fichier</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1062"/>
+        <location filename="retext.py" line="1165"/>
         <source>Export document to ODT</source>
         <translation>Exporter document vers ODT</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1062"/>
+        <location filename="retext.py" line="1165"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>Fichier text OpenDocument (*.odt)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1071"/>
+        <location filename="retext.py" line="1174"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>Fichier HTML (*.html, *.htm)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1094"/>
+        <location filename="retext.py" line="1197"/>
         <source>Export document to PDF</source>
         <translation>Exporter document vers PDF</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1094"/>
+        <location filename="retext.py" line="1197"/>
         <source>PDF files (*.pdf)</source>
         <translation>Fichiers PDF (*.pdf)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1109"/>
+        <location filename="retext.py" line="1212"/>
         <source>Print document</source>
         <translation>Imprimer document</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1158"/>
-        <source>This function is not available in Plain text mode!</source>
-        <translation>Cette fonctionnalité n&apos;est pas disponible en mode Texte !</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="1161"/>
-        <source>Select type</source>
-        <translation>Choisir Type</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="1128"/>
+        <location filename="retext.py" line="1231"/>
         <source>Export document</source>
         <translation>Exporter document</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1224"/>
+        <location filename="retext.py" line="1316"/>
         <source>Incorrect user name or password!</source>
         <translation>Utilisateur ou mot de passe incorrect !</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1299"/>
+        <location filename="retext.py" line="1395"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>Le document a changé.
 Voulez vous enregistrer vos changements ?</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1337"/>
+        <location filename="retext.py" line="1428"/>
         <source>HTML code</source>
         <translation>Code HTML</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1346"/>
+        <location filename="retext.py" line="1437"/>
         <source>Simple but powerful editor for Markdown and ReStructuredText</source>
         <translation>Éditeur de Markdown et ReStructuredText simple mais puissant</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1346"/>
+        <location filename="retext.py" line="1437"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>Auteur :Dmity Schachnev, 2011</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1346"/>
+        <location filename="retext.py" line="1437"/>
         <source>Website</source>
         <translation>Site Web</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1346"/>
+        <location filename="retext.py" line="1437"/>
         <source>Markdown syntax</source>
         <translation>Syntaxe Markdown</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1346"/>
+        <location filename="retext.py" line="1437"/>
         <source>ReST syntax</source>
         <translation>Syntaxe Rest</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1411"/>
+        <location filename="retext.py" line="1488"/>
         <source>Could not parse file contents, check if you have the necessary module installed!</source>
         <translation>Ne peut analyser le contenu du fichier, vérifier si les modules sont bien installés</translation>
     </message>
     <message>
-        <location filename="retext.py" line="802"/>
+        <location filename="retext.py" line="905"/>
         <source>Show directory</source>
         <translation>Montrer répertoire</translation>
     </message>
     <message>
-        <location filename="retext.py" line="807"/>
+        <location filename="retext.py" line="910"/>
         <source>Webpages generator is not installed!</source>
         <translation>Générateur Webpages non installé !</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1008"/>
+        <location filename="retext.py" line="1112"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>Ne peut enregistrer le fichier car en lecture seule !</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1227"/>
+        <location filename="retext.py" line="1319"/>
         <source>Authentification failed, please check your internet connection!</source>
         <translation>Authentification echouée, svp vérifier votre connection internet !</translation>
     </message>
     <message>
-        <location filename="retext.py" line="368"/>
+        <location filename="retext.py" line="394"/>
         <source>Bold</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="retext.py" line="369"/>
+        <location filename="retext.py" line="395"/>
         <source>Italic</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="retext.py" line="370"/>
+        <location filename="retext.py" line="396"/>
         <source>Underline</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="retext.py" line="461"/>
+        <location filename="retext.py" line="485"/>
         <source>Formatting</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="retext.py" line="344"/>
+        <location filename="retext.py" line="370"/>
         <source>About %s</source>
         <translation>À propos de %s</translation>
     </message>
     <message>
-        <location filename="retext.py" line="327"/>
+        <location filename="retext.py" line="353"/>
         <source>Use WebKit renderer</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="retext.py" line="1151"/>
+        <location filename="retext.py" line="1255"/>
         <source>Failed to execute the command:</source>
         <translation type="unfinished"></translation>
     </message>
