@@ -3,17 +3,17 @@
 <context>
     <name>LogPassDialog</name>
     <message>
-        <location filename="retext.py" line="175"/>
+        <location filename="retext.py" line="208"/>
         <source>Enter your Google account data</source>
         <translation>Введите данные вашего аккаунта Google</translation>
     </message>
     <message>
-        <location filename="retext.py" line="184"/>
+        <location filename="retext.py" line="217"/>
         <source>Username</source>
         <translation>Имя пользователя</translation>
     </message>
     <message>
-        <location filename="retext.py" line="185"/>
+        <location filename="retext.py" line="218"/>
         <source>Password</source>
         <translation>Пароль</translation>
     </message>
@@ -21,439 +21,414 @@
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="retext.py" line="253"/>
+        <location filename="retext.py" line="295"/>
         <source>Open</source>
         <translation>Открыть</translation>
     </message>
     <message>
-        <location filename="retext.py" line="255"/>
+        <location filename="retext.py" line="297"/>
         <source>Save</source>
         <translation>Сохранить</translation>
     </message>
     <message>
-        <location filename="retext.py" line="260"/>
+        <location filename="retext.py" line="302"/>
         <source>Print</source>
         <translation>Распечатать</translation>
     </message>
     <message>
-        <location filename="retext.py" line="270"/>
+        <location filename="retext.py" line="312"/>
         <source>Preview</source>
         <translation>Просмотр</translation>
     </message>
     <message>
-        <location filename="retext.py" line="380"/>
+        <location filename="retext.py" line="406"/>
         <source>Tags</source>
         <translation>Теги</translation>
     </message>
     <message>
-        <location filename="retext.py" line="384"/>
+        <location filename="retext.py" line="410"/>
         <source>Symbols</source>
         <translation>Символы</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1071"/>
+        <location filename="retext.py" line="1174"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>Файлы HTML (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1071"/>
+        <location filename="retext.py" line="1174"/>
         <source>Save file</source>
         <translation>Сохранить файл</translation>
     </message>
     <message>
-        <location filename="retext.py" line="258"/>
+        <location filename="retext.py" line="300"/>
         <source>Save as</source>
         <translation>Сохранить как</translation>
     </message>
     <message>
-        <location filename="retext.py" line="294"/>
+        <location filename="retext.py" line="329"/>
         <source>Quit</source>
         <translation>Выход</translation>
     </message>
     <message>
-        <location filename="retext.py" line="347"/>
+        <location filename="retext.py" line="373"/>
         <source>About Qt</source>
         <translation>О Qt</translation>
     </message>
     <message>
-        <location filename="retext.py" line="408"/>
+        <location filename="retext.py" line="433"/>
         <source>File</source>
         <translation>Файл</translation>
     </message>
     <message>
-        <location filename="retext.py" line="409"/>
+        <location filename="retext.py" line="434"/>
         <source>Edit</source>
         <translation>Правка</translation>
     </message>
     <message>
-        <location filename="retext.py" line="410"/>
+        <location filename="retext.py" line="435"/>
         <source>Help</source>
         <translation>Справка</translation>
     </message>
     <message>
-        <location filename="retext.py" line="424"/>
+        <location filename="retext.py" line="449"/>
         <source>Export</source>
         <translation>Экспорт</translation>
     </message>
     <message>
-        <location filename="retext.py" line="245"/>
+        <location filename="retext.py" line="287"/>
         <source>File toolbar</source>
         <translation>Панель файла</translation>
     </message>
     <message>
-        <location filename="retext.py" line="247"/>
+        <location filename="retext.py" line="289"/>
         <source>Edit toolbar</source>
         <translation>Панель редактирования</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1094"/>
+        <location filename="retext.py" line="1197"/>
         <source>Export document to PDF</source>
         <translation>Экспортировать документ как PDF</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1094"/>
+        <location filename="retext.py" line="1197"/>
         <source>PDF files (*.pdf)</source>
         <translation>Файлы PDF (*.pdf)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1299"/>
+        <location filename="retext.py" line="1395"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>Документ был изменён.
 Сохранить изменения?</translation>
     </message>
     <message>
-        <location filename="retext.py" line="297"/>
+        <location filename="retext.py" line="332"/>
         <source>Undo</source>
         <translation>Отменить действие</translation>
     </message>
     <message>
-        <location filename="retext.py" line="299"/>
+        <location filename="retext.py" line="334"/>
         <source>Redo</source>
         <translation>Повторить действие</translation>
     </message>
     <message>
-        <location filename="retext.py" line="301"/>
+        <location filename="retext.py" line="336"/>
         <source>Copy</source>
         <translation>Копировать</translation>
     </message>
     <message>
-        <location filename="retext.py" line="303"/>
+        <location filename="retext.py" line="338"/>
         <source>Cut</source>
         <translation>Вырезать</translation>
     </message>
     <message>
-        <location filename="retext.py" line="305"/>
+        <location filename="retext.py" line="340"/>
         <source>Paste</source>
         <translation>Вставить</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1330"/>
+        <location filename="retext.py" line="1421"/>
         <source>New document</source>
         <translation>Новый документ</translation>
     </message>
     <message>
-        <location filename="retext.py" line="929"/>
+        <location filename="retext.py" line="1032"/>
         <source>All files (*)</source>
         <translation>Все файлы (*)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="251"/>
+        <location filename="retext.py" line="293"/>
         <source>New</source>
         <translation>Новый</translation>
     </message>
     <message>
-        <location filename="retext.py" line="413"/>
+        <location filename="retext.py" line="438"/>
         <source>Open recent</source>
         <translation>Открыть последние</translation>
     </message>
     <message>
-        <location filename="retext.py" line="325"/>
+        <location filename="retext.py" line="351"/>
         <source>Plain text</source>
         <translation>Простой текст</translation>
     </message>
     <message>
-        <location filename="retext.py" line="373"/>
+        <location filename="retext.py" line="399"/>
         <source>Save to Google Docs</source>
         <translation>Сохранить в Google Docs</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1224"/>
+        <location filename="retext.py" line="1316"/>
         <source>Incorrect user name or password!</source>
         <translation>Неверное имя пользователя или пароль!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1062"/>
+        <location filename="retext.py" line="1165"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>Файлы текста OpenDocument (*.odt)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1062"/>
+        <location filename="retext.py" line="1165"/>
         <source>Export document to ODT</source>
         <translation>Экспортировать документ как ODT</translation>
     </message>
     <message>
-        <location filename="retext.py" line="264"/>
+        <location filename="retext.py" line="306"/>
         <source>View HTML code</source>
         <translation>Просмотр кода HTML</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1337"/>
+        <location filename="retext.py" line="1428"/>
         <source>HTML code</source>
         <translation>код HTML</translation>
     </message>
     <message>
-        <location filename="retext.py" line="262"/>
+        <location filename="retext.py" line="304"/>
         <source>Print preview</source>
         <translation>Предпросмотр печати</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1109"/>
+        <location filename="retext.py" line="1212"/>
         <source>Print document</source>
         <translation>Распечатать документ</translation>
     </message>
     <message>
-        <location filename="retext.py" line="279"/>
+        <location filename="retext.py" line="321"/>
         <source>Live preview</source>
         <translation>Живой просмотр</translation>
     </message>
     <message>
-        <location filename="retext.py" line="800"/>
+        <location filename="retext.py" line="903"/>
         <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
         <translation>Веб-страницы сохранены в папке &lt;code&gt;html&lt;/code&gt;.</translation>
     </message>
     <message>
-        <location filename="retext.py" line="813"/>
+        <location filename="retext.py" line="916"/>
         <source>Please, save the file somewhere.</source>
         <translation>Сначала сохраните файл.</translation>
     </message>
     <message>
-        <location filename="retext.py" line="334"/>
+        <location filename="retext.py" line="360"/>
         <source>Generate webpages</source>
         <translation>Создать веб-страницы</translation>
     </message>
     <message>
-        <location filename="retext.py" line="984"/>
+        <location filename="retext.py" line="1091"/>
         <source>Plain text (*.txt)</source>
         <translation>Простой текст (*.txt)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="335"/>
+        <location filename="retext.py" line="361"/>
         <source>Show</source>
         <translation>Показать</translation>
     </message>
     <message>
-        <location filename="retext.py" line="416"/>
+        <location filename="retext.py" line="441"/>
         <source>Directory</source>
         <translation>Папка</translation>
     </message>
     <message>
-        <location filename="retext.py" line="929"/>
+        <location filename="retext.py" line="1032"/>
         <source>Supported files</source>
         <translation>Поддерживаемые файлы</translation>
     </message>
     <message>
-        <location filename="retext.py" line="265"/>
+        <location filename="retext.py" line="307"/>
         <source>Change default font</source>
         <translation>Изменить стандартный шрифт</translation>
     </message>
     <message>
-        <location filename="retext.py" line="288"/>
-        <source>Other formats</source>
-        <translation>Другие форматы</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="1161"/>
-        <source>Select type</source>
-        <translation>Выберите тип</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="1128"/>
+        <location filename="retext.py" line="1231"/>
         <source>Export document</source>
         <translation>Экспортировать документ</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1158"/>
-        <source>This function is not available in Plain text mode!</source>
-        <translation>Эта функция недоступна в режиме простого текста!</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="526"/>
-        <source>Only HTML formatting will be available.</source>
-        <translation>Будет доступно только HTML-форматирование.</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="315"/>
+        <location filename="retext.py" line="349"/>
         <source>Enable</source>
         <translation>Включить</translation>
     </message>
     <message>
-        <location filename="retext.py" line="316"/>
+        <location filename="retext.py" line="350"/>
         <source>Set locale</source>
         <translation>Установить локаль</translation>
     </message>
     <message>
-        <location filename="retext.py" line="450"/>
+        <location filename="retext.py" line="474"/>
         <source>Spell check</source>
         <translation>Проверка орфографии</translation>
     </message>
     <message>
-        <location filename="retext.py" line="726"/>
+        <location filename="retext.py" line="819"/>
         <source>Enter locale name (example: en_US)</source>
         <translation>Введите код локали (например: en_US)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="281"/>
+        <location filename="retext.py" line="323"/>
         <source>Fullscreen mode</source>
         <translation>Полноэкранный режим</translation>
     </message>
     <message>
-        <location filename="retext.py" line="249"/>
+        <location filename="retext.py" line="291"/>
         <source>Search toolbar</source>
         <translation>Панель поиска</translation>
     </message>
     <message>
-        <location filename="retext.py" line="266"/>
+        <location filename="retext.py" line="308"/>
         <source>Find text</source>
         <translation>Поиск текста</translation>
     </message>
     <message>
-        <location filename="retext.py" line="336"/>
+        <location filename="retext.py" line="362"/>
         <source>Next</source>
         <translation>Следующее</translation>
     </message>
     <message>
-        <location filename="retext.py" line="337"/>
+        <location filename="retext.py" line="363"/>
         <source>Previous</source>
         <translation>Предыдущее</translation>
     </message>
     <message>
-        <location filename="retext.py" line="458"/>
+        <location filename="retext.py" line="482"/>
         <source>Default editing mode</source>
         <translation>Стандартный режим редактирования</translation>
     </message>
     <message>
-        <location filename="retext.py" line="499"/>
+        <location filename="retext.py" line="523"/>
         <source>Search</source>
         <translation>Поиск</translation>
     </message>
     <message>
-        <location filename="retext.py" line="503"/>
+        <location filename="retext.py" line="526"/>
         <source>Case sensitively</source>
         <translation>Учитывать регистр</translation>
     </message>
     <message>
-        <location filename="retext.py" line="526"/>
+        <location filename="retext.py" line="563"/>
         <source>You have neither Markdown nor Docutils modules installed!</source>
         <translation>У вас не установлен ни один из модулей Markdown и Docutils!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="990"/>
-        <source>HTML files</source>
-        <translation>Файлы HTML</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="1346"/>
+        <location filename="retext.py" line="1437"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>Автор: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1346"/>
+        <location filename="retext.py" line="1437"/>
         <source>Website</source>
         <translation>Веб-сайт</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1346"/>
+        <location filename="retext.py" line="1437"/>
         <source>Markdown syntax</source>
         <translation>Синтаксис Markdown</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1346"/>
+        <location filename="retext.py" line="1437"/>
         <source>ReST syntax</source>
         <translation>Синтаксис ReST</translation>
     </message>
     <message>
-        <location filename="retext.py" line="987"/>
+        <location filename="retext.py" line="1094"/>
         <source>ReStructuredText files</source>
         <translation>Файлы ReStructuredText</translation>
     </message>
     <message>
-        <location filename="retext.py" line="993"/>
+        <location filename="retext.py" line="1097"/>
         <source>Markdown files</source>
         <translation>Файлы Markdown</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1346"/>
+        <location filename="retext.py" line="1437"/>
         <source>Simple but powerful editor for Markdown and ReStructuredText</source>
         <translation>Простой, но мощный редактор для Markdown и ReStructuredText</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1411"/>
+        <location filename="retext.py" line="1488"/>
         <source>Could not parse file contents, check if you have the necessary module installed!</source>
         <translation>Невозможно обработать содержимое файла, убедитесь, что установлен необходимый модуль!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="929"/>
+        <location filename="retext.py" line="1032"/>
         <source>Select one or several files to open</source>
         <translation>Выберите один или несколько файлов для открытия</translation>
     </message>
     <message>
-        <location filename="retext.py" line="339"/>
+        <location filename="retext.py" line="365"/>
         <source>Get help online</source>
         <translation>Получить помощь в интернете</translation>
     </message>
     <message>
-        <location filename="retext.py" line="802"/>
+        <location filename="retext.py" line="905"/>
         <source>Show directory</source>
         <translation>Открыть папку</translation>
     </message>
     <message>
-        <location filename="retext.py" line="807"/>
+        <location filename="retext.py" line="910"/>
         <source>Webpages generator is not installed!</source>
         <translation>Генератор веб-страниц не установлен!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1008"/>
+        <location filename="retext.py" line="1112"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>Невозможно сохранить в файл, так как он доступен только для чтения!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1227"/>
+        <location filename="retext.py" line="1319"/>
         <source>Authentification failed, please check your internet connection!</source>
         <translation>Не удалось подключиться, проверьте ваше интернет-соединение!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="368"/>
+        <location filename="retext.py" line="394"/>
         <source>Bold</source>
         <translation>Полужирный</translation>
     </message>
     <message>
-        <location filename="retext.py" line="369"/>
+        <location filename="retext.py" line="395"/>
         <source>Italic</source>
         <translation>Курсив</translation>
     </message>
     <message>
-        <location filename="retext.py" line="370"/>
+        <location filename="retext.py" line="396"/>
         <source>Underline</source>
         <translation>Подчёркивание</translation>
     </message>
     <message>
-        <location filename="retext.py" line="461"/>
+        <location filename="retext.py" line="485"/>
         <source>Formatting</source>
         <translation>Форматирование</translation>
     </message>
     <message>
-        <location filename="retext.py" line="344"/>
+        <location filename="retext.py" line="370"/>
         <source>About %s</source>
         <translation>О %s</translation>
     </message>
     <message>
-        <location filename="retext.py" line="327"/>
+        <location filename="retext.py" line="353"/>
         <source>Use WebKit renderer</source>
         <translation>Использовать движок WebKit</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1151"/>
+        <location filename="retext.py" line="1255"/>
         <source>Failed to execute the command:</source>
         <translation>Невозможно запустить команду:</translation>
     </message>
