@@ -3,17 +3,17 @@
 <context>
     <name>LogPassDialog</name>
     <message>
-        <location filename="retext.py" line="175"/>
+        <location filename="retext.py" line="208"/>
         <source>Enter your Google account data</source>
         <translation>請輸入您的 Google 帳號訊息</translation>
     </message>
     <message>
-        <location filename="retext.py" line="184"/>
+        <location filename="retext.py" line="217"/>
         <source>Username</source>
         <translation>用戶名</translation>
     </message>
     <message>
-        <location filename="retext.py" line="185"/>
+        <location filename="retext.py" line="218"/>
         <source>Password</source>
         <translation>密鑰或應用程式碼（適用于兩步式認証的 Google 帳號）</translation>
     </message>
@@ -21,438 +21,413 @@
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="retext.py" line="253"/>
+        <location filename="retext.py" line="295"/>
         <source>Open</source>
         <translation>開啟</translation>
     </message>
     <message>
-        <location filename="retext.py" line="255"/>
+        <location filename="retext.py" line="297"/>
         <source>Save</source>
         <translation>儲存</translation>
     </message>
     <message>
-        <location filename="retext.py" line="260"/>
+        <location filename="retext.py" line="302"/>
         <source>Print</source>
         <translation>列印</translation>
     </message>
     <message>
-        <location filename="retext.py" line="270"/>
+        <location filename="retext.py" line="312"/>
         <source>Preview</source>
         <translation>預覽</translation>
     </message>
     <message>
-        <location filename="retext.py" line="380"/>
+        <location filename="retext.py" line="406"/>
         <source>Tags</source>
         <translation>書籤</translation>
     </message>
     <message>
-        <location filename="retext.py" line="384"/>
+        <location filename="retext.py" line="410"/>
         <source>Symbols</source>
         <translation>特殊符號</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1071"/>
+        <location filename="retext.py" line="1174"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>HTML 檔案 (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1071"/>
+        <location filename="retext.py" line="1174"/>
         <source>Save file</source>
         <translation>儲存檔案</translation>
     </message>
     <message>
-        <location filename="retext.py" line="258"/>
+        <location filename="retext.py" line="300"/>
         <source>Save as</source>
         <translation>另存新檔</translation>
     </message>
     <message>
-        <location filename="retext.py" line="294"/>
+        <location filename="retext.py" line="329"/>
         <source>Quit</source>
         <translation>離開</translation>
     </message>
     <message>
-        <location filename="retext.py" line="347"/>
+        <location filename="retext.py" line="373"/>
         <source>About Qt</source>
         <translation>關於 Qt</translation>
     </message>
     <message>
-        <location filename="retext.py" line="408"/>
+        <location filename="retext.py" line="433"/>
         <source>File</source>
         <translation>檔案</translation>
     </message>
     <message>
-        <location filename="retext.py" line="409"/>
+        <location filename="retext.py" line="434"/>
         <source>Edit</source>
         <translation>編輯</translation>
     </message>
     <message>
-        <location filename="retext.py" line="410"/>
+        <location filename="retext.py" line="435"/>
         <source>Help</source>
         <translation>說明</translation>
     </message>
     <message>
-        <location filename="retext.py" line="424"/>
+        <location filename="retext.py" line="449"/>
         <source>Export</source>
         <translation>匯出</translation>
     </message>
     <message>
-        <location filename="retext.py" line="245"/>
+        <location filename="retext.py" line="287"/>
         <source>File toolbar</source>
         <translation>檔案工具列</translation>
     </message>
     <message>
-        <location filename="retext.py" line="247"/>
+        <location filename="retext.py" line="289"/>
         <source>Edit toolbar</source>
         <translation>編輯工具列</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1094"/>
+        <location filename="retext.py" line="1197"/>
         <source>Export document to PDF</source>
         <translation>匯出檔案到 PDF</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1094"/>
+        <location filename="retext.py" line="1197"/>
         <source>PDF files (*.pdf)</source>
         <translation>PDF 檔案 (*.pdf)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1299"/>
+        <location filename="retext.py" line="1395"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>檔案已變更，確定儲存嗎？</translation>
     </message>
     <message>
-        <location filename="retext.py" line="297"/>
+        <location filename="retext.py" line="332"/>
         <source>Undo</source>
         <translation>復原</translation>
     </message>
     <message>
-        <location filename="retext.py" line="299"/>
+        <location filename="retext.py" line="334"/>
         <source>Redo</source>
         <translation>重做</translation>
     </message>
     <message>
-        <location filename="retext.py" line="301"/>
+        <location filename="retext.py" line="336"/>
         <source>Copy</source>
         <translation>複製</translation>
     </message>
     <message>
-        <location filename="retext.py" line="303"/>
+        <location filename="retext.py" line="338"/>
         <source>Cut</source>
         <translation>剪下</translation>
     </message>
     <message>
-        <location filename="retext.py" line="305"/>
+        <location filename="retext.py" line="340"/>
         <source>Paste</source>
         <translation>貼上</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1330"/>
+        <location filename="retext.py" line="1421"/>
         <source>New document</source>
         <translation>新檔</translation>
     </message>
     <message>
-        <location filename="retext.py" line="929"/>
+        <location filename="retext.py" line="1032"/>
         <source>All files (*)</source>
         <translation>所有檔案 (*)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="251"/>
+        <location filename="retext.py" line="293"/>
         <source>New</source>
         <translation>新增</translation>
     </message>
     <message>
-        <location filename="retext.py" line="413"/>
+        <location filename="retext.py" line="438"/>
         <source>Open recent</source>
         <translation>開啟最近的</translation>
     </message>
     <message>
-        <location filename="retext.py" line="325"/>
+        <location filename="retext.py" line="351"/>
         <source>Plain text</source>
         <translation>純文本</translation>
     </message>
     <message>
-        <location filename="retext.py" line="373"/>
+        <location filename="retext.py" line="399"/>
         <source>Save to Google Docs</source>
         <translation>匯出到 Google Docs</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1224"/>
+        <location filename="retext.py" line="1316"/>
         <source>Incorrect user name or password!</source>
         <translation>用戶名或密鑰不正確!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1062"/>
+        <location filename="retext.py" line="1165"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>Libreoffice 檔案 (*.odt)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1062"/>
+        <location filename="retext.py" line="1165"/>
         <source>Export document to ODT</source>
         <translation>匯出檔案到 ODT</translation>
     </message>
     <message>
-        <location filename="retext.py" line="264"/>
+        <location filename="retext.py" line="306"/>
         <source>View HTML code</source>
         <translation>檢視 HTML 程式碼</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1337"/>
+        <location filename="retext.py" line="1428"/>
         <source>HTML code</source>
         <translation>HTML 程式碼</translation>
     </message>
     <message>
-        <location filename="retext.py" line="262"/>
+        <location filename="retext.py" line="304"/>
         <source>Print preview</source>
         <translation>列印預覽</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1109"/>
+        <location filename="retext.py" line="1212"/>
         <source>Print document</source>
         <translation>列印檔案</translation>
     </message>
     <message>
-        <location filename="retext.py" line="279"/>
+        <location filename="retext.py" line="321"/>
         <source>Live preview</source>
         <translation>同步預覽</translation>
     </message>
     <message>
-        <location filename="retext.py" line="800"/>
+        <location filename="retext.py" line="903"/>
         <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
         <translation>網頁儲存在 &lt;code&gt;html&lt;/code&gt; 目錄。</translation>
     </message>
     <message>
-        <location filename="retext.py" line="813"/>
+        <location filename="retext.py" line="916"/>
         <source>Please, save the file somewhere.</source>
         <translation>請，儲存到別的地方呦！</translation>
     </message>
     <message>
-        <location filename="retext.py" line="334"/>
+        <location filename="retext.py" line="360"/>
         <source>Generate webpages</source>
         <translation>產生網頁</translation>
     </message>
     <message>
-        <location filename="retext.py" line="984"/>
+        <location filename="retext.py" line="1091"/>
         <source>Plain text (*.txt)</source>
         <translation>純文本 (*.txt)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="335"/>
+        <location filename="retext.py" line="361"/>
         <source>Show</source>
         <translation>顯示</translation>
     </message>
     <message>
-        <location filename="retext.py" line="416"/>
+        <location filename="retext.py" line="441"/>
         <source>Directory</source>
         <translation>目錄</translation>
     </message>
     <message>
-        <location filename="retext.py" line="929"/>
+        <location filename="retext.py" line="1032"/>
         <source>Supported files</source>
         <translation>支持的檔案格式</translation>
     </message>
     <message>
-        <location filename="retext.py" line="265"/>
+        <location filename="retext.py" line="307"/>
         <source>Change default font</source>
         <translation>變更預設字型</translation>
     </message>
     <message>
-        <location filename="retext.py" line="288"/>
-        <source>Other formats</source>
-        <translation>其他格式</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="1161"/>
-        <source>Select type</source>
-        <translation>選擇類型</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="1128"/>
+        <location filename="retext.py" line="1231"/>
         <source>Export document</source>
         <translation>匯出檔案</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1158"/>
-        <source>This function is not available in Plain text mode!</source>
-        <translation>該功能無法在純文本模式下使用！</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="526"/>
-        <source>Only HTML formatting will be available.</source>
-        <translation>只有 HTML 格式才供應。</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="315"/>
+        <location filename="retext.py" line="349"/>
         <source>Enable</source>
         <translation>啟用</translation>
     </message>
     <message>
-        <location filename="retext.py" line="316"/>
+        <location filename="retext.py" line="350"/>
         <source>Set locale</source>
         <translation>選擇程式語言</translation>
     </message>
     <message>
-        <location filename="retext.py" line="450"/>
+        <location filename="retext.py" line="474"/>
         <source>Spell check</source>
         <translation>拼寫檢查</translation>
     </message>
     <message>
-        <location filename="retext.py" line="726"/>
+        <location filename="retext.py" line="819"/>
         <source>Enter locale name (example: en_US)</source>
         <translation>輸入語言名字 (例如: en_US)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="281"/>
+        <location filename="retext.py" line="323"/>
         <source>Fullscreen mode</source>
         <translation>全螢幕</translation>
     </message>
     <message>
-        <location filename="retext.py" line="249"/>
+        <location filename="retext.py" line="291"/>
         <source>Search toolbar</source>
         <translation>尋找工具列</translation>
     </message>
     <message>
-        <location filename="retext.py" line="266"/>
+        <location filename="retext.py" line="308"/>
         <source>Find text</source>
         <translation>尋找文本</translation>
     </message>
     <message>
-        <location filename="retext.py" line="336"/>
+        <location filename="retext.py" line="362"/>
         <source>Next</source>
         <translation>下一條</translation>
     </message>
     <message>
-        <location filename="retext.py" line="337"/>
+        <location filename="retext.py" line="363"/>
         <source>Previous</source>
         <translation>上一條</translation>
     </message>
     <message>
-        <location filename="retext.py" line="458"/>
+        <location filename="retext.py" line="482"/>
         <source>Default editing mode</source>
         <translation>預設編輯模式</translation>
     </message>
     <message>
-        <location filename="retext.py" line="499"/>
+        <location filename="retext.py" line="523"/>
         <source>Search</source>
         <translation>尋找</translation>
     </message>
     <message>
-        <location filename="retext.py" line="503"/>
+        <location filename="retext.py" line="526"/>
         <source>Case sensitively</source>
         <translation>對大小写敏感</translation>
     </message>
     <message>
-        <location filename="retext.py" line="526"/>
+        <location filename="retext.py" line="563"/>
         <source>You have neither Markdown nor Docutils modules installed!</source>
         <translation>你既沒有安裝 Markdown 也没有 Docutils 模塊!</translation>
     </message>
     <message>
-        <location filename="retext.py" line="990"/>
-        <source>HTML files</source>
-        <translation>HTML 檔案</translation>
-    </message>
-    <message>
-        <location filename="retext.py" line="1346"/>
+        <location filename="retext.py" line="1437"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>作者: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1346"/>
+        <location filename="retext.py" line="1437"/>
         <source>Website</source>
         <translation>部落格</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1346"/>
+        <location filename="retext.py" line="1437"/>
         <source>Markdown syntax</source>
         <translation>Markdown 句法</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1346"/>
+        <location filename="retext.py" line="1437"/>
         <source>ReST syntax</source>
         <translation>ReST 句法</translation>
     </message>
     <message>
-        <location filename="retext.py" line="987"/>
+        <location filename="retext.py" line="1094"/>
         <source>ReStructuredText files</source>
         <translation>ReStructuredText 檔案</translation>
     </message>
     <message>
-        <location filename="retext.py" line="993"/>
+        <location filename="retext.py" line="1097"/>
         <source>Markdown files</source>
         <translation>Markdown 檔案</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1346"/>
+        <location filename="retext.py" line="1437"/>
         <source>Simple but powerful editor for Markdown and ReStructuredText</source>
         <translation>簡單高效的 Markdown 與 ReStructuredText 編輯器</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1411"/>
+        <location filename="retext.py" line="1488"/>
         <source>Could not parse file contents, check if you have the necessary module installed!</source>
         <translation>不能處理檔案內容，檢查你是否安裝了必要的模塊！</translation>
     </message>
     <message>
-        <location filename="retext.py" line="929"/>
+        <location filename="retext.py" line="1032"/>
         <source>Select one or several files to open</source>
         <translation>選擇一個或多個檔案以開啟</translation>
     </message>
     <message>
-        <location filename="retext.py" line="339"/>
+        <location filename="retext.py" line="365"/>
         <source>Get help online</source>
         <translation>在線擷取幫助（英文）</translation>
     </message>
     <message>
-        <location filename="retext.py" line="802"/>
+        <location filename="retext.py" line="905"/>
         <source>Show directory</source>
         <translation>顯示目錄</translation>
     </message>
     <message>
-        <location filename="retext.py" line="807"/>
+        <location filename="retext.py" line="910"/>
         <source>Webpages generator is not installed!</source>
         <translation>網頁生成器未安裝！</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1008"/>
+        <location filename="retext.py" line="1112"/>
         <source>Cannot save to file because it is read-only!</source>
         <translation>不能儲存檔案因为它是只讀的！</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1227"/>
+        <location filename="retext.py" line="1319"/>
         <source>Authentification failed, please check your internet connection!</source>
         <translation>驗証失敗，請核查您的網絡連接！</translation>
     </message>
     <message>
-        <location filename="retext.py" line="368"/>
+        <location filename="retext.py" line="394"/>
         <source>Bold</source>
         <translation>加粗</translation>
     </message>
     <message>
-        <location filename="retext.py" line="369"/>
+        <location filename="retext.py" line="395"/>
         <source>Italic</source>
         <translation>傾斜</translation>
     </message>
     <message>
-        <location filename="retext.py" line="370"/>
+        <location filename="retext.py" line="396"/>
         <source>Underline</source>
         <translation>下劃線</translation>
     </message>
     <message>
-        <location filename="retext.py" line="461"/>
+        <location filename="retext.py" line="485"/>
         <source>Formatting</source>
         <translation>樣式</translation>
     </message>
     <message>
-        <location filename="retext.py" line="344"/>
+        <location filename="retext.py" line="370"/>
         <source>About %s</source>
         <translation>關於 %s</translation>
     </message>
     <message>
-        <location filename="retext.py" line="327"/>
+        <location filename="retext.py" line="353"/>
         <source>Use WebKit renderer</source>
         <translation>使用WebKit渲染</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1151"/>
+        <location filename="retext.py" line="1255"/>
         <source>Failed to execute the command:</source>
         <translation>不能執行指令:</translation>
     </message>
